import 'dart:async';

import 'package:flutter/services.dart';
import 'dart:io' show Platform;

enum AppKillerAction { actionAutostart, actionNotifications, actionPowersaving }

AppKillerAction _parceAction(String string) {
  switch (string) {
    case 'action_autostart':
      return AppKillerAction.actionAutostart;
    case 'action_notifications':
      return AppKillerAction.actionNotifications;
    case 'action_powersaving':
      return AppKillerAction.actionPowersaving;
    default:
      return null;
  }
}

String _actionString(AppKillerAction action) {
  switch (action) {
    case AppKillerAction.actionAutostart:
      return 'action_autostart';
    case AppKillerAction.actionNotifications:
      return 'action_notifications';
    case AppKillerAction.actionPowersaving:
      return 'action_powersaving';
    default:
      return null;
  }
}

class AppKillerManagerAndroid {
  static const MethodChannel _channel = const MethodChannel('bioniq.com/app_killer_manager');

  static Future<List<AppKillerAction>> get availableActions async {
    if (!Platform.isAndroid) {
      return [];
    }
    final version = await _channel.invokeMapMethod<String, bool>('availableActions').catchError(print);
    return version.entries.where((entry) => entry.value).map((entry) => _parceAction(entry.key)).toList();
  }

  static Future<bool> startIntent(AppKillerAction action) async {
    if (!Platform.isAndroid) {
      return false;
    }
    return await _channel.invokeMethod('startIntent', {'action': _actionString(action)});
  }
}
